@@ -1,9 +1,13 @@
 """Implementation of Optimal F1 score based on TorchMetrics."""
+
+# Copyright (C) 2022 Intel Corporation
+# SPDX-License-Identifier: Apache-2.0
+
 import torch
-from torchmetrics import Metric, PrecisionRecallCurve
+from torchmetrics import PrecisionRecallCurve
 
 
-class AdaptiveThreshold(Metric):
+class AdaptiveThreshold(PrecisionRecallCurve):
     """Optimal F1 Metric.
 
     Compute the optimal F1 score at the adaptive threshold, based on the F1 metric of the true labels and the
@@ -11,17 +15,11 @@ class AdaptiveThreshold(Metric):
     """
 
     def __init__(self, default_value: float = 0.5, **kwargs):
-        super().__init__(**kwargs)
+        super().__init__(num_classes=1, **kwargs)
 
-        self.precision_recall_curve = PrecisionRecallCurve(num_classes=1)
         self.add_state("value", default=torch.tensor(default_value), persistent=True)  # pylint: disable=not-callable
         self.value = torch.tensor(default_value)  # pylint: disable=not-callable
 
-    # pylint: disable=arguments-differ
-    def update(self, preds: torch.Tensor, target: torch.Tensor) -> None:  # type: ignore
-        """Update the precision-recall curve metric."""
-        self.precision_recall_curve.update(preds, target)
-
     def compute(self) -> torch.Tensor:
         """Compute the threshold that yields the optimal F1 score.
 
@@ -35,7 +33,7 @@ class AdaptiveThreshold(Metric):
         recall: torch.Tensor
         thresholds: torch.Tensor
 
-        precision, recall, thresholds = self.precision_recall_curve.compute()
+        precision, recall, thresholds = super().compute()
         f1_score = (2 * precision * recall) / (precision + recall + 1e-10)
         if thresholds.dim() == 0:
             # special case where recall is 1.0 even for the highest threshold.
