@@ -1,18 +1,7 @@
 """Module that tracks the min and max values of the observations in each batch."""
 
-# Copyright (C) 2020 Intel Corporation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-# http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing,
-# software distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions
-# and limitations under the License.
+# Copyright (C) 2022 Intel Corporation
+# SPDX-License-Identifier: Apache-2.0
 
 from typing import Tuple
 
@@ -24,6 +13,8 @@ from torchmetrics import Metric
 class MinMax(Metric):
     """Track the min and max values of the observations in each batch."""
 
+    full_state_update: bool = True
+
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         self.add_state("min", torch.tensor(float("inf")), persistent=True)  # pylint: disable=not-callable
