@@ -1,4 +1,8 @@
 """Implementation of Optimal F1 score based on TorchMetrics."""
+
+# Copyright (C) 2022 Intel Corporation
+# SPDX-License-Identifier: Apache-2.0
+
 import torch
 from torchmetrics import Metric, PrecisionRecallCurve
 
@@ -10,6 +14,8 @@ class OptimalF1(Metric):
     predicted anomaly scores.
     """
 
+    full_state_update: bool = False
+
     def __init__(self, num_classes: int, **kwargs):
         super().__init__(**kwargs)
 
@@ -40,3 +46,7 @@ class OptimalF1(Metric):
         self.threshold = thresholds[torch.argmax(f1_score)]
         optimal_f1_score = torch.max(f1_score)
         return optimal_f1_score
+
+    def reset(self) -> None:
+        """Reset the metric."""
+        self.precision_recall_curve.reset()
